*******
Autodoc
*******

Ansible Galaxy
==============

.. autoclass:: molecule.ansible_galaxy.AnsibleGalaxy
   :members:

Ansible Playbook
================

.. autoclass:: molecule.ansible_playbook.AnsiblePlaybook
   :members:

.. include:: command.rst

Config
======

.. autoclass:: molecule.config.Config
   :members:

.. autoclass:: molecule.config.ConfigV1
   :members:

.. include:: driver.rst

Molecule
========

.. autoclass:: molecule.core.Molecule
   :members:

State
=====

.. autoclass:: molecule.state.InvalidState
   :members:

.. autoclass:: molecule.state.State
   :members:

Util
====

.. automodule:: molecule.util
   :members:

.. include:: verifier.rst
